@@ -1,4 +1,4 @@
-#line 2 methmakename(__FILE__)
+#line 2 methmakename(code_accessor_h)
 
 static void
 THIS_OP_NAME(pTHX_ AV *av, const char *p_s, int dim, carray_form format)
